==> netbeans_6.8.orig.tar.gz: netbeans-6.8/kenai/src/org/netbeans/modules/kenai/api/KenaiProjectMember.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2009 Sun Microsystems, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Sun in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2009 Sun Microsystems, Inc.
 */

package org.netbeans.modules.kenai.api;

import org.netbeans.modules.kenai.UserData;

/**
 * Represents member of project.
 * It contains reference to KenaiUser and his Role.
 *
 * @author Jan Becicka
 */
public final class KenaiProjectMember {

    private final KenaiUser user;
    private final Role role;
    KenaiProjectMember(UserData userData) {
        if ("registered".equals(userData.role)) {
            this.role = Role.OBSERVER;
        } else {
            this.role= Role.valueOf(userData.role.toUpperCase());
        }
        this.user = KenaiUser.get(userData);
    }

    /**
     * member's user name
     * @return
     */
    public String getUserName() {
        return user.data.user_name;

    }

    /**
     * reference to KenaiUser
     * @return
     */
    public KenaiUser getKenaiUser() {
        return user;
    }

    /**
     * Members role in project
     * @return
     */
    public Role getRole() {
        return role;
    }

    /**
     * user role in projects
     */
    public static enum Role {
        ADMIN,
        DEVELOPER,
        CONTENT,
        OBSERVER
    }
}

==> netbeans_6.9.orig.tar.gz: netbeans-6.9/kenai/src/org/netbeans/modules/kenai/api/KenaiProjectMember.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2010 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2009 Sun Microsystems, Inc.
 */

package org.netbeans.modules.kenai.api;

import org.netbeans.modules.kenai.UserData;

/**
 * Represents member of project.
 * It contains reference to KenaiUser and his Role.
 *
 * @author Jan Becicka
 */
public final class KenaiProjectMember {

    private final KenaiUser user;
    private Role role;
    KenaiProjectMember(Kenai kenai, UserData userData) {
        if ("registered".equals(userData.role)) {
            this.role = Role.OBSERVER;
        } else {
            try {
                this.role = Role.valueOf(userData.role.toUpperCase());
            } catch (IllegalArgumentException iae) {
                this.role = Role.UNKNOWN;
            }
        }
        this.user = KenaiUser.get(kenai, userData);
    }

    /**
     * member's short user name
     * @return
     */
    public String getUserName() {
        return user.data.user_name;

    }

    /**
     * reference to KenaiUser
     * @return
     */
    public KenaiUser getKenaiUser() {
        return user;
    }

    /**
     * Members role in project
     * @return
     */
    public Role getRole() {
        return role;
    }

    /**
     * user role in projects
     */
    public static enum Role {
        ADMIN,
        DEVELOPER,
        CONTENT,
        OBSERVER,
        TESTER,
        UNKNOWN;

        @Override
        public String toString() {
            if (this==OBSERVER) {
                return "registered";
            }
            return super.toString().toLowerCase();
        }
    }
}
